NicePercent

Struct NicePercent 

pub struct NicePercent { /* private fields */ }
Nice Percent.

This struct can be used to quickly and efficiently stringify a “percent” — a float between 0.0..=1.0 — to a fixed precision of hundredths.

Values outside that range are “clamped” to make them make sense, percentage-wise. (NaN and negative values are treated like zero; large positives like one.)

Examples

use dactyl::NicePercent;

// From a ready-made float:
assert_eq!(
    NicePercent::from(0.55012345_f32).as_str(),
    "55.01%",
);

// From separate "done" and "total" integers.
assert_eq!(
    NicePercent::from((20_usize, 800_usize)).as_str(),
    "2.50%",
);

// From weird shit.
assert_eq!(
    NicePercent::from(-0.55012345_f32).as_str(), // Negative.
    "0.00%",
);
assert_eq!(
    NicePercent::from(f64::NAN).as_str(), // Not even a number!
    "0.00%",
);
assert_eq!(
    NicePercent::from(f64::NEG_INFINITY).as_str(), // Negative.
    "0.00%",
);
assert_eq!(
    NicePercent::from(55.012345_f32).as_str(), // Wrong scale.
    "100.00%",
);
assert_eq!(
    NicePercent::from(f64::INFINITY).as_str(), // So much more than one.
    "100.00%",
);

Implementations

Source

impl NicePercent

pub const MIN: Self

Minimum Value.

The nice equivalent of 0.0.

Examples
use dactyl::NicePercent;

assert_eq!(
    NicePercent::MIN.as_str(),
    "0.00%",
);
pub const MAX: Self

Maximum Value.

The nice equivalent of 1.0.

Examples
use dactyl::NicePercent;

assert_eq!(
    NicePercent::MAX.as_str(),
    "100.00%",
);
Source

impl NicePercent

pub const fn as_bytes(&self) -> &[u8]

As Byte Slice.

Return the value as a byte slice.

Examples
use dactyl::NicePercent;

assert_eq!(
    NicePercent::from(1.0_f32).as_bytes(),
    b"100.00%",
);
pub const fn as_str(&self) -> &str

As String Slice.

Return the value as a string slice.

Examples
use dactyl::NicePercent;

assert_eq!(
    NicePercent::from(1.0_f32).as_str(),
    "100.00%",
);
pub const fn is_empty(&self) -> bool

Is Empty?

No! Haha. But for consistency, this method exists.

pub const fn len(&self) -> usize

Length.

Return the length of the nice byte/string representation.

Note this will never be zero.

Examples
use dactyl::NicePercent;

let nice = NicePercent::MAX;
assert_eq!(
    nice.len(),
    nice.as_str().len(),
);
Source

impl NicePercent

pub fn replace(&mut self, num: f32)

Replace.

Reuse the backing storage behind self to hold a new nice percent.

Examples.
use dactyl::NicePercent;

let mut num = NicePercent::from(0.85);
assert_eq!(num.as_str(), "85.00%");

num.replace(0.334);
assert_eq!(num.as_str(), "33.40%");